package sun.java2d;

import sun.java2d.loops.Blit;
import sun.awt.image.BufImgSurfaceData;
import java.awt.image.BufferedImage;
import java.awt.image.WritableRaster;
import java.awt.image.Raster;
import sun.java2d.loops.XORComposite;
import java.awt.AlphaComposite;
import sun.java2d.loops.CompositeType;
import java.awt.Composite;
import java.awt.image.ColorModel;
import java.awt.CompositeContext;

public class SunCompositeContext implements CompositeContext
{
    ColorModel srcCM;
    ColorModel dstCM;
    Composite composite;
    CompositeType comptype;
    
    public SunCompositeContext(AlphaComposite alphaComposite, ColorModel srcCM, ColorModel dstCM) {
        if (srcCM == null) {
            throw new NullPointerException("Source color model cannot be null");
        }
        if (dstCM == null) {
            throw new NullPointerException("Destination color model cannot be null");
        }
        this.srcCM = srcCM;
        this.dstCM = dstCM;
        this.composite = alphaComposite;
        this.comptype = CompositeType.forAlphaComposite(alphaComposite);
        return;
    }
    
    public SunCompositeContext(XORComposite composite, ColorModel srcCM, ColorModel dstCM) {
        if (srcCM == null) {
            throw new NullPointerException("Source color model cannot be null");
        }
        if (dstCM == null) {
            throw new NullPointerException("Destination color model cannot be null");
        }
        this.srcCM = srcCM;
        this.dstCM = dstCM;
        this.composite = composite;
        this.comptype = CompositeType.Xor;
        return;
    }
    
    @Override
    public void dispose() {
    }
    
    @Override
    public void compose(Raster inRaster, Raster inRaster2, WritableRaster raster) {
        if (inRaster2 != raster) {
            raster.setDataElements(0, 0, inRaster2);
        }
        WritableRaster compatibleWritableRaster;
        if ((inRaster instanceof WritableRaster)) {
            compatibleWritableRaster = (WritableRaster)inRaster;
        }
        else {
            compatibleWritableRaster = inRaster.createCompatibleWritableRaster();
            compatibleWritableRaster.setDataElements(0, 0, inRaster);
        }
        int min = Math.min(compatibleWritableRaster.getWidth(), inRaster2.getWidth());
        int min2 = Math.min(compatibleWritableRaster.getHeight(), inRaster2.getHeight());
        BufferedImage bufImg = new BufferedImage(this.srcCM, compatibleWritableRaster, this.srcCM.isAlphaPremultiplied(), null);
        BufferedImage bufImg2 = new BufferedImage(this.dstCM, raster, this.dstCM.isAlphaPremultiplied(), null);
        SurfaceData data = BufImgSurfaceData.createData(bufImg);
        SurfaceData data2 = BufImgSurfaceData.createData(bufImg2);
        Blit.getFromCache(data.getSurfaceType(), this.comptype, data2.getSurfaceType()).Blit(data, data2, this.composite, null, 0, 0, 0, 0, min, min2);
    }
}
